/// Support for both RCON protocol.
/// Refer to:
///  https://developer.valvesoftware.com/wiki/Source_RCON_Protocol
///  https://wiki.vg/RCON
///  for the protocol documentation.
library source_server;

import 'dart:async';
import 'dart:io';

import 'src/rcon_socket.dart';

export 'src/exceptions.dart';
export 'src/rcon_socket.dart';

/// Minecraft Rcon implementation.
class MinecraftServer {
  /// The remote server address.
  final InternetAddress address;

  /// The remote server port.
  final int port;

  /// The remote server password;
  final String password;

  RconSocket _rcon;

  /// Direct access to the [RconSocket].
  RconSocket get rcon => _rcon;

  /// [MinecraftServer] constructor,
  /// [connect] must be called in order to establish the connection
  /// to the Query and RCON servers.
  MinecraftServer(this.address, this.port, this.password) {
    _rcon = RconSocket(address, port, password, skipFirst: false);
  }

  /// Establishes the connection to the Rcon server.
  Future<void> connect() => rcon.connect();

  /// Sends a command to the RCON server and returns
  /// a future that completes with its reply.
  Future<String> send(String command) => rcon.send(command);

  /// Closes the connection to the remote RCON server.
  void close() => rcon.close();
}
